@@ -14,6 +14,23 @@ class QualityChecker(object):
         if obj.dropna(axis='columns').empty:
             raise AttributeError("DataFrame is empty!!! What quality do you expect from emptiness")
 
+    def _apply_quantile(self, node):
+        column_name = node.children[0]
+        q = float(node.children[1])
+        c = node.children[2]
+        rhs = float(node.children[3])
+        lhs = self._obj[column_name].quantile(q)
+        if c == ">":
+            return node.data, lhs > rhs
+        elif c == "==":
+            return node.data, lhs == rhs
+        elif c == "<":
+            return node.data, lhs < rhs
+        else:
+            return node.data, False
+
+
+
     def _apply_check(self, check):
         try:
             c = check[0]
@@ -32,6 +49,20 @@ class QualityChecker(object):
             elif c.data == "not_null":
                 column_name = c.children[0]
                 return c.data, self._obj[column_name].isna().sum() == 0
+            elif c.data == "is_positive":
+                column_name = c.children[0]
+                return c.data, (self._obj[column_name] > 0).all()
+            elif c.data == "is_in":
+                column_name = c.children[0]
+                allowed_values = []
+                unique_values = self._obj[column_name].unique()
+                for ct in c.children[1].children:
+                    value = ct.value
+                    allowed_values.insert(0, value.replace("'", ""))
+
+                return c.data, all(elem in allowed_values  for elem in unique_values)
+            elif c.data == "quantile":
+                return self._apply_quantile(c)
             else:
                 return c.data, False
         except KeyError:
